@@ -8,9 +8,12 @@
 #' diagonal values are counted as zero. Same value is used in isSymmetric function.
 #' @return Transformed matrix with D in diagonal, L in strictly lower diagonal 
 #' and zeros on upper diagonal.
-ldl <- function(x, tol = max(abs(diag(x))) * .Machine$double.eps) {  
+ldl <- 
+  function(x, tol = max(abs(diag(x))) * .Machine$double.eps) {
     if (!isSymmetric(x, tol = tol)) 
         stop("Matrix is not symmetric!")
-    out <- .Fortran(fldl, x = x, as.integer(dim(x)[1]), tol = tol,info=integer(1))
-    out$x    
+    out <- .Fortran(fldl, x = x, as.integer(dim(x)[1]), tol = tol, info = integer(1))
+    if(out$info!=0)
+      stop("Matrix x is not positive semidefinite.")
+    out$x
 } 
