@@ -8,7 +8,8 @@ test_that("SSModel works properly",{
     model<-SSModel(t12~SSMcycle(period=10, type='common',Q=2)
                    +SSMcycle(period=10, type='distinct',P1=diag(c(1,1,2,2)),Q=diag(1:2))
                    +SSMtrend(2,type="common",Q=diag(c(1,0.5)))
-                   +SSMtrend(2,type="distinct",Q=list(diag(0.1,2),diag(0.01,2)),P1=diag(c(0.1,0.01,0.1,0.01)))
+                   +SSMtrend(2,type="distinct",Q=list(diag(0.1,2),diag(0.01,2)),
+                             P1=diag(c(0.1,0.01,0.1,0.01)))
                    +SSMseasonal(period=4,type="common")
                    +SSMseasonal(period=4,type="distinct",Q=diag(c(2,3)),P1=diag(c(2,2,2,3,3,3)))
                    +SSMseasonal(period=5,type="common",sea.type="trig")
@@ -18,9 +19,9 @@ test_that("SSModel works properly",{
     ),not(gives_warning()))
   expect_that(print(model),not(gives_warning()))
   expect_that(logLik(model),not(gives_warning()))
-  expect_equal(logLik(model),-443.011122738032,tolerance=tol,check.attributes=FALSE)
+  expect_equal(logLik(model),-431.983860339576,tolerance=tol,check.attributes=FALSE)
   expect_that(out<-KFS(model,filtering=c("state","mean"),smoothing=c("state","mean","disturbance")),
               not(gives_warning()))
   expect_equal(out$d,11)
   expect_equal(out$j,1)
-})
\ No newline at end of file
+})
